SyncManager class

Constructors

SyncManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

config SyncConfig
getter/setter pair

Static Methods

initialize({SyncConfig? syncConfig}) Future<void>
processQueue() Future<void>
request({required String method, required String url, Map<String, dynamic>? body, Map<String, dynamic>? headers}) Future<void>