QueuedRequest class
Constructors
-
QueuedRequest({required String id, required String url, required String method, Map<
String, dynamic> ? body, Map<String, dynamic> ? headers, required DateTime createdAt, int retryCount = 0}) - QueuedRequest.fromJson(String source)
-
factory
-
QueuedRequest.fromMap(Map<
String, dynamic> map) -
factory
Properties
-
body
→ Map<
String, dynamic> ? -
final
- createdAt → DateTime
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, dynamic> ? -
final
- id → String
-
final
- method → String
-
final
- retryCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited